import java.io.File;

import org.gephi.filters.api.FilterController;
import org.gephi.filters.api.Query;
import org.gephi.filters.api.Range;
import org.gephi.filters.plugin.dynamic.DynamicRangeBuilder;
import org.gephi.filters.plugin.dynamic.DynamicRangeBuilder.DynamicRangeFilter;
import org.gephi.filters.spi.FilterBuilder;
import org.gephi.graph.api.GraphController;
import org.gephi.graph.api.GraphModel;
import org.gephi.graph.api.GraphView;
import org.gephi.io.importer.api.Container;
import org.gephi.io.importer.api.ImportController;
import org.gephi.io.processor.plugin.DefaultProcessor;
import org.gephi.project.api.ProjectController;
import org.gephi.project.api.Workspace;
import org.openide.util.Lookup;

public class TestMemory {

    public void doIt() {
        //Init a project - and therefore a workspace
        ProjectController pc = Lookup.getDefault().lookup(ProjectController.class);
        pc.newProject();
        Workspace workspace = pc.getCurrentWorkspace();

        //Get controllers and models
        ImportController importController = Lookup.getDefault().lookup(ImportController.class);

        //Import file
        Container container;
        try {
            File file = new File("test.gexf");
            container = importController.importFile(file);
        } catch (Exception ex) {
            ex.printStackTrace();
            return;
        }

        //Append imported data to GraphAPI
        importController.process(container, new DefaultProcessor(), workspace);
        
        //Get a graph model - it exists because we have a workspace
        GraphModel graphModel = Lookup.getDefault().lookup(GraphController.class).getModel();

//        TimelineController timelineController = Lookup.getDefault().lookup(TimelineController.class);

        double min = 1.297435492E12; //timelineController.getModel().getMinValue();

        //Create a dynamic range filter query
        FilterController filterController = Lookup.getDefault().lookup(FilterController.class);
        FilterBuilder[] builders = Lookup.getDefault().lookup(DynamicRangeBuilder.class).getBuilders();
        DynamicRangeFilter dynamicRangeFilter = (DynamicRangeFilter) builders[0].getFilter();     //There is only one TIME_INTERVAL column, so it's always the [0] builder
        Query dynamicQuery = filterController.createQuery(dynamicRangeFilter);
        filterController.add(dynamicQuery);

        for (int i=0; i<=3600; i++) {
        	
            dynamicRangeFilter.setRange(new Range(min, min+(i*1000)));
            GraphView view = filterController.filter(dynamicQuery);
//            Graph filteredGraph = graphModel.getGraph(view);

            graphModel.setVisibleView(view);
            
            System.out.println(i);
            
        }
    }

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        new TestMemory().doIt();
    }

}
